/*
 *  ESNetscapePlugin.h
 *  Flash'In'App
 *
 *  Copyright 2009 Eltima Software. All rights reserved.
 *
 *	Flash'In'App is not free since version 2.0.
 *	If you plan to integrate it in your project, please, purchase a license at http://mac.eltima.com/flashinapp.html
 *	Questions? Please, contact Eltima at sales@eltima.com or visit http://mac.eltima.com for more info
 *  Full usage and integration guide can be found here: http://wiki.eltima.com/user-guides/flash-in-app-macos.html
 */

#import <Cocoa/Cocoa.h>

@interface ESFIAPreferences : NSObject
{
  BOOL _overrideMouseCursor;
  BOOL _overrideSoundVolume;
  float _soundVolume;
  NSMutableArray *_arrAudioUnits;
  NSMutableArray *_arrSndChannels;
  
  NSString *_registrationName;
  NSString *_registrationKey;
  
  NSString *_flashPluginPath;

  NSString *_realPluginPath;
  NSMutableArray *_realViews;
  
  NSString *_silverPluginPath;
}

/*
 * Returns the shared ESFIAPreferences instance, creating it if necessary.
 */
+ (id) sharedPreferences;

/*
 * This method lets you specify whether Flash'In'App should override mouse cursor changes
 * E.g. when using ESFlashView, if you change ZoomRect, then Adobe Flash Player plugin will apply "hand" cursor 
 */
- (void) setShouldOverrideMouseCursor:(BOOL)aFlag;
- (BOOL) shouldOverrideMouseCursor;

/*
 * This method lets you specify whether Flash'In'App should override volume settings
 * NOTE, that this setting will be applied to the whole application
 */
- (BOOL) shouldOverrideSoundVolume;
- (void) setShouldOverrideSoundVolume:(BOOL)aFlag;

/*
 * Set/get sound volume
 * NOTE, that it will be applied only if shouldOverrideSoundVolume returns YES
 */
- (void) setSoundVolume:(float)aVolume;
- (float) soundVolume;
- (BOOL) isSoundMuted;

/*
 * set/get Flash'In'App registration name and key
 * IMPORTANT! setName:andKey: method has to be called before loading any movie to register Flash'In'App, otherwise a demo reminder will be shown to user
 */
- (void) setName:(NSString *)aName andKey:(NSString *)aKey;
- (NSString *) registrationName;
- (NSString *) registrationKey;

/*
 * set/get path to the Flash Player plugin
 * by default plugin will be loaded from Contents/PlugIns/Flash Player.plugin
 
 * flashPluginPath - returns current path to the plugin
 * setFlashPluginPath: - sets the new value for this setting (cannot be nil and should point to existing path)
 */
- (void) setFlashPluginPath:(NSString *)aPath;
- (NSString *) flashPluginPath;

/*
 * set/get path to the RealPlayer Plugin plugin
 * by default plugin will be loaded from /Library/Internet Plug-Ins/RealPlayer Plugin.plugin
 
 * realPlayerPluginPath - returns current path to the plugin
 * setRealPlayerPluginPath: - sets the new value for this setting (cannot be nil and should point to existing path)
 */
- (void) setRealPlayerPluginPath:(NSString *)aPath;
- (NSString *) realPlayerPluginPath;

/*
 * set/get path to the Silverlight plugin
 * by default plugin will be loaded from /Library/Internet Plug-Ins/Silverlight.plugin
 
 * silverlightPlayerPluginPath - returns current path to the plugin
 * setSilverlightPluginPath: - sets the new value for this setting (cannot be nil and should point to existing path)
 */
- (void) setSilverlightPluginPath:(NSString *)aPath;
- (NSString *) silverlightPluginPath;

@end
